# -*- coding: cp1252 -*-

# File:     TCAlgo_ReferenceFunctions.py
# Project: 	Reference functions needed for sub-steps of the algorithm.
# Author:	Axel Newe (axel.newe@fau.de)
# Version:	1.0
# Date: 	2015-11-11

# ------------------------------------------------------------------------------------------------------

import numpy as np

# ------------------------------------------------------------------------------------------------------

def ReferenceFunc_Constant(values, c = 0):
    """
    This is a reference function that returns a list of constant values with the same length as a given reference value list.
    :param values: A list of lab values or reference days.
    :param c: The constant value that shall be used for creating the list.
    :return: A list of constant values, e.g. [1,1,1,1,1,1]
    """

    return [c] * len(values)


def ReferenceFunc_Linear(values, a = 0, c = 0):
    """
    This is a reference function that returns a list of values that form a linear function: a * x + c
    :param values: A list of lab values or reference days.
    :param a: The slope coefficient for the linear function.
    :param c: The constant for the linear function.
    :return: A list of constant values, e.g. [1.0,1.1,1.2,1.3,1.4,1.5]
    """

    result = []

    for x in values:
        result += [a*x+c]

    return result
