# -*- coding: cp1252 -*-

# File:     TCAlgo_TestExecution.py
# Project: 	Main program for testing the Algo implementation.
# Author:	Axel Newe (axel.newe@fau.de)
# Version:	1.0
# Date: 	2015-11-11

# ------------------------------------------------------------------------------------------------------

import TCAlgo_Tools
import TCAlgo_XMLTools
import TCAlgo_AlgoImplementation

# ------------------------------------------------------------------------------------------------------

def main():
    """
    This is the main function to test the algorithm implementation.
    It reads the ground truth data (or any other data XML matching the pecification),
	executes the algorithm (i.e., performs the automatic assessment) for each data set 
	and writes the result to an XML file.
    """

    localPath = TCAlgo_Tools.GetLocalPath()

    # Read payload data from ground truth
    NormalizedLabValueEpisodesDict = TCAlgo_XMLTools.ImportDataXML(localPath + '/temporal_correlation_groundtruth.xml')

    # Set parameters
    noChangeIfInReferenceRange = False #True
    params = (noChangeIfInReferenceRange)

    # Call the main processing loop
    AssessmentDataDict = TCAlgo_AlgoImplementation.PerformAssessmentForAllNormalizedLabValueEpisodes(NormalizedLabValueEpisodesDict, params)

    # Export results
    TCAlgo_XMLTools.ExportCurveAssessmentDataToXML(localPath + '/algorithm_assesssment_result.xml', AssessmentDataDict)

    return

# Execute main()
main()


